Sign in

bbbbbr

@bbbbbr.bsky.social
867 followers 453 following 931 posts

Scrapper. Napper. Occasional bit pusher Game Boy games & Carts: bbbbbr.itch.io (Wordyl, Petris, QR-Paint, etc) GBDK dev team member MegaDuck info: megaduck.dev

PostsRepliesMedia
bbbbbr @bbbbbr.bsky.social · 24/09/2026
In the quest (hopefully not futile) to use a single vblank interrupt source across most #casioloopy emus (can't right now), I wrote a test ROM for it. Not sure emu maintainers, who have their own things to do, will use it. I've done some emu work but am not good at it. github.com/bbbbbr/loopy...
Screenshot of a interrupt test rom running on a casio loopy console. It shows various interrupt sources (nmi, irq0, irq1) and all of them passing
081
bbbbbr @bbbbbr.bsky.social · 19/09/2026
Was trying to get nmi and irq0 interrupts working (for vblank shadow oam copy) and dabbled with hblank some. Stumbled across this nice twisty bar effect. Camera footage since emus I can run don't support the interrupts 🥲. New loopy MiSTer core handles it reasonably well (little jitter aside)
091
bbbbbr @bbbbbr.bsky.social · 18/09/2026
The #Petris port to #CasioLoopy console becoming very playable. Feels good to cross that threshold. Still lots of jank and polish needed. The (incomplete) frog border evolved out of re-using shrub tiles & need to fill extra screen space compared to Game Boy Color. Might try for various pet borders.
081
bbbbbr @bbbbbr.bsky.social · 17/09/2026
We have pets, and they are gettin' long! Scrapped and redid half my porting changes to the #Petris gameplay logic. Way cleaner and working gameplay came together much faster. Obvs still screen cleanup and game notification porting to do, but that should be more straightforward. #casioloopy #loopy
041
bbbbbr @bbbbbr.bsky.social · 12/09/2026
Petris Title and Settings screens progress on #CasioLoopy. Two layers of parallax semi-transparent clouds and sine text wiggle. Settings logic came over with minor changes. With more #gbdk api compat done porting is going faster. Turning out to be a pleasant console to dev on. #retrogaming #loopy
0123
bbbbbr @bbbbbr.bsky.social · 09/09/2026
(From last week) ~Full RGB444 rendering on the #casio #loopy using blend mode. Hardware palette is 256 colors, but also has 2 "screen" layers that can be blended. So I put the Blue channel on one screen (1 pal) and Red X Green (15 pals) on the other. Output looks good! About 4k colors. #casioloopy
3142
bbbbbr @bbbbbr.bsky.social · 09/09/2026
Ran into glitches running port in progress on real loopy hardware. Issue was not present in the emulator. My mistake was loading tile data w/ 8 bit access, vram seems to require 16 bit access. 16 is faster anyway until I start using DMA. Made a small test ROM for that scenario. #casioloopy
Screenshot of the Petris title screen with vertical line glitches on hardwareComparison of the test rom output. On the left solid blue with solid red beneath it, this is failing. On the right, from hardware, is vertical bars of blue/black on the top and solid green beneath it. Screenshot of the Petris title screen with NO vertical line glitches on hardware
160
bbbbbr @bbbbbr.bsky.social · 04/09/2026
A funny thing about porting from Game Boy to a console with a higher res screen is figuring out what to do with all the extra space. In this case playing around with a nicer font and more background on the options screen. Time and experience help too. Font is BoldPixels by @yukipixels.bsky.social
Screen shot of a game options screen a blue  background, some green bushes and ground, and brown beneath it. There is pink and yellow text at the top of the screen which has a color tinted drop shadow.
On the screen is the text repeated twice:
Type: Long Pet
Level: Normal
Screen shot of a Game Boy emulator showing an options screen with a blue background and some gradient at the top.
On the screen is the text:
Options
Type: Long Pet
Level: Normal
Music: Twilight
Start Game
2 Player Vs: Off
Hi Contrast: Off
Visual Hints: Off
151
bbbbbr @bbbbbr.bsky.social · 27/08/2026
Seems like half the time I spend learning to write homebrew for a new console is making idiosyncratic tooling... Compact non-python ones must be out there, maybe just hard to find? Ended up writing a little console RGB color bit depth reducer for PNGs.
Linux console output with text:

$ png2reducedrgb -h
png2reducedrgb: RGB bit depth reducer (by bbbbbr)
              Version: 1.0.0

usage: tilepalquant <file>.png [options]
-o <filename>          Ouput file (if not used then default is <png file>_out.png)
-h                     Show this help output
-v                     Verbose output (-vv for extra debug output)
-bit_depth <r,g,b>     Bits per RGB channel output (1-8 per channel, default: 5,5,5)
                         Example: "-bit_depth_out 5,5,5"
-output_order_bgr      Write BGR order for raw binary output (default: RGB)
-output_little_endian  Write little endian (low bytes first) for raw binary output (default: big)
-output_png            Output a PNG file instead of raw binary data
-output_c              Output a C source file and header instead of raw binary data
-use_metafile          Read extra options from file <inputfile>.meta (missing not an error)

Example usage: tilepalquant in.png -bit_depth_out 5,5,5 -o rgb_out.bin

$ png2reducedrgb rgb888_range_test.png -o rgb555_range_test.bin -v -bit_depth 5,5,5
truncating to: 5,5,5
PNG Loaded: rgb888_range_test.png: Image size 256 x 224
$
3101
bbbbbr @bbbbbr.bsky.social · 13/08/2026
aten_panzana released patch for #gameboy #Pokemon Red/Blue on #MegaDuck. (based on the pret disasm) On hardware requires MD2+MBC5 SRAM cart. Theres demo picoDuck firmware & upcoming flash carts. Can also run in SuperJunior SameDuck emu (".md25s" ext) Patch: aten-panzana.itch.io/mega-duck-pa...
pokemon title screen running on a megaduck consolepokemon game running on a megaduck consolepokemon title screen running on a megaduck consolepokemon title screen running on a megaduck emualtor
0112
bbbbbr @bbbbbr.bsky.social · 05/08/2026
The legendary #Workboy found a new home! I ported the ROM to work on the #MegaDuck laptop (a #GameBoy clone). Not the hardware we wanted, but...it's hardware that exists! Keyboard, Real Time Clock and all. Free #DuckDuckWorkboy #rompatch on the itch page: bbbbbr.itch.io/mega-duck-pa... #romhacking
3359
bbbbbr @bbbbbr.bsky.social · 03/08/2026
New release of #SuperJuniorSameDuck (my fork of SameBoy with #MegaDuck laptop support) - Support ".md2s" file extension (MD2 mapper + SRAM) - Preserve VRAM on "Load Cart From Slot" command, allows ROMs to detect whether they are running on Spanish vs German laptop model github.com/bbbbbr/Super...
github.com
Release SuperJuniorSameDuck v1.0.2 · bbbbbr/SuperJuniorSameDuck
SuperJuniorSameDuck v1.0.2 Changes Added support for .md2s file extension that automatically enables SRAM for MD2 mbcs without requiring --duck-sram-cart Added MBC5 detection from filename Ad...
030
bbbbbr @bbbbbr.bsky.social · 01/08/2026
Found a hidden treasure in #GameBoy #Workboy ROM (looking for Bank 0 free space) Menu shown when run without keyboard connected has hidden "Backup Options" entry. To reveal search for "ITCMRT" in phone app (cart sram must be init-ed). Appears to Dump/Restore cart SRAM to keyboard over link port.
160
bbbbbr @bbbbbr.bsky.social · 30/07/2026
New release: little #GameBoy and #MegaDuck on-console memory hex viewer / editor. Made it for inspecting save data on the Duck Laptop where the SRAM can be on a separate cart than the ROM. Possibly of use for casual Game Boy memory peeking and poking too. github.com/bbbbbr/gameb...
Screenshot of hex editor running in a game boy emulator. There is a gred of hex numbers in the middle with hex address information on the left side. The bottom says "Wr Value, Write @:FF47 <- F9". Running in dark mode.Screenshot of hex editor running in a game boy emulator. There is a gred of hex numbers in the middle with hex address information on the left side. The bottom says "Wr Value, Write @:FF47 <- F9".
0194
bbbbbr @bbbbbr.bsky.social · 16/07/2026
Made a source-patch #MegaDuck port of the recent #Celeste Classic #GameBoy version by Rous/joshop. Playable and fun even on blurry oem screens. bbbbbr.itch.io/megaduck-cel... Patch and binary made and shared with permission, only needed minor edits to get it running on the good duck. #retrogaming
Celeste classic title screen running on a handheld megaduck clone consoleCeleste classic gameplay running on a megaduck clone consoleCeleste classic gameplay running on a megaduck clone consoleCeleste classic title screen running on a laptop megaduck clone console
0226
bbbbbr @bbbbbr.bsky.social · 11/07/2026
Some tiny #megaduck console icons drawn and rom patched into the title screen.
Pixel art icons in greenish 4 color style of Mega Duck handheld console and Laptop model console. Both are around 18x18 pixels
0110
bbbbbr @bbbbbr.bsky.social · 11/07/2026
Taking a short break from main project for a quick afternoon #MegaDuck port of someone else's new (open source) homebrew Game Boy game. Only minor changes required to get it running. Hope to be able to release it soon. Surprisingly playable on laptop model considering blurry low contrast screen.
Photograph of a Mega Duck laptop console showing part of it's keyboard and all of it's screen. On the faded, low contrast green-scale screen is a level from the Game Boy port of Celeste.
071
bbbbbr @bbbbbr.bsky.social · 06/07/2026
😉 #megaduck
Screenshot of a megaduck console screen showing a calendar
180
bbbbbr @bbbbbr.bsky.social · 16/06/2026
Poll results are in! Mostly the same as 2024. (Whats MAIN way people play #GameBoy / Color games) Combined results from Mastodon, Bluesky, and barely any Twitter this year. Very un-scientific and un-rigorous! 😅 #gbdev #gameboycolor #retrogaming #gbdk #gbstudio #rgbds
Poll with the title:  MAIN way people play Game Boy / Color games (2024 & 2026)

Results for the bar charts:

2026					
Type						% Share
GB + Unmodded OEM			18.18%
GB + IPS mod				19.19%
Handheld Emulator / FPGA	41.41%
Desktop / Phone Emulators	21.21%
					
2024					
Type						% Share
GB + Unmodded OEM			18.18%
GB + IPS mod				19.19%
Handheld Emulator / FPGA	41.41%
Desktop / Phone Emulators	21.21%
3152
Reposted by bbbbbr
bbbbbr @bbbbbr.bsky.social · 11/06/2026
Been few years, return of GB Screen poll! What's MAIN way you play #GameBoy /Color games? Curious since supporting OEM screen takes effort for devs. No bsky poll, choose a number! 1. GB +Unmodded OEM Screen 2. GB +IPS mod screen 3. Handheld Emulator/FPGA 4. Desktop/Phone Emulator 5. SGB/GBPlayer
2081
bbbbbr @bbbbbr.bsky.social · 11/06/2026
Been few years, return of GB Screen poll! What's MAIN way you play #GameBoy /Color games? Curious since supporting OEM screen takes effort for devs. No bsky poll, choose a number! 1. GB +Unmodded OEM Screen 2. GB +IPS mod screen 3. Handheld Emulator/FPGA 4. Desktop/Phone Emulator 5. SGB/GBPlayer
2081
bbbbbr @bbbbbr.bsky.social · 08/06/2026
New minor release of tilepalquant: v1.0.1 It adds some standard presets for various consoles ( #GameBoyColor, #GameGear, etc). (a c++ port of rilden's tile based color palette reducer for game consoles) github.com/bbbbbr/tilep...
github.com
Release tilepalquant 1.0.1 · bbbbbr/tilepalquant
tilepalquant version 1.0.1 Changes since 1.0.0 Add -preset option to select from custom defaults for various consoles $ bin/tilepalquant -help_presets tilepalquant presets (use with -preset <mode...
030
bbbbbr @bbbbbr.bsky.social · 24/05/2026
Ported rilden's (web) image palette reducer to a command line app, easier to use in project build toolchains. Great for making images fit game console Tiles x N Palette x N Color limits github.com/bbbbbr/tilep... Original here: rilden.github.io/tiledpalette... #retrogaming #gameboy #nes #megadrive
github.com
Release tilepalquant 0.9.8 · bbbbbr/tilepalquant
tilepalquant version 0.9.8 Initial release porting rilden's JS tiledpalettequant to C++ Most features and options are carried over. The changes are: Deterministic output instead of varying each ru...
2112
Reposted by bbbbbr
David Couzelis @drcouzelis.bsky.social · 24/05/2026
I (finally) posted a video of highlights fom the 2025 #gameboy game jam! Check it out to learn about some of the notable entries. 😊 youtu.be/JI5649nTCJQ
youtu.be
Highlights from the 2025 Game Boy game jam - GB Compo 25
YouTube video by David Couzelis
4127
bbbbbr @bbbbbr.bsky.social · 23/05/2026
Cool to see another project making use of the SFC/SNES mouse on the Suepr Game Boy! Hope to see some GBBasic projects that use it. Also credit to vinheim3 for the original SGB mouse patches and concept.
0222
bbbbbr @bbbbbr.bsky.social · 26/04/2026
Fun video by @catgraffam.bsky.social about drawing with QR-Paint, go check it out! Plus a new release which adds the Undo/Redo hotkeys mentioned in the video. bbbbbr.itch.io/game-boy-qr-... #gameboy #pixelart #retrogaming
bbbbbr.itch.io
Game Boy QR-Paint by bbbbbr
Draw on the Game Boy and share it direct to your phone using a QRCode! (without the internet!)
0131
Reposted by bbbbbr
Cat Graffam @catgraffam.bsky.social · 26/04/2026
New video is live! youtu.be/FG3AZgY8lac
youtu.be
I Tried to Draw in MS Paint...For the Game Boy? | CAT COPIES
YouTube video by Cat Graffam
619143
bbbbbr @bbbbbr.bsky.social · 18/04/2026
Two taxidermied birds at a museum #gameboycamera #gameboy #photography
Pixelated photograph of a taxidermied crow perched on a twigPixelated close up photograph of a taxidermied bird head with detail of the eye and hooked beak
0161
Reposted by bbbbbr
zwenergy @zwenergy.bsky.social · 13/04/2026
If there's one thing the world needs - it's RGB modding a Tiger game•com.
3164
bbbbbr @bbbbbr.bsky.social · 31/03/2026
Did an IPS screen mod for the Supaboy handheld #SNES clone. Viewing angles are soooo much better. I'm really bad at getting flex cables into their connectors, but eventually prevailed.
Photograph of a supaboy snes clone viewed from below such that the screen image colors are inverted due to poor viewing angles.Photograph of a supaboy snes clone viewed from below at a similar angles, with the new screen the image colors are no longer inverted and are clearly reproduced.
1120
bbbbbr @bbbbbr.bsky.social · 16/03/2026
OK, apparently couldn't resist one more feature in #QRPaint (v0.9.4). Added a Spray tool with a slightly over-engineered random spray and flow rate. 😄 bbbbbr.itch.io/game-boy-qr-... #Gameboy #Megaduck #pixelart #retrogaming
Screenshot of qrpaint in a game boy emulator, there is a drawing of a mountain ridge in black with dithered white highlights on the left side of the peaks and a dithered sky going from top (dark) to bottom (light) and a black moon or sun.Screenshot of qrpaint in a game boy emulator, there is a drawing showing different sizes and durations of the spray tool with lower and higher densities of random pixels (lighter and darker overall effect).
2233
bbbbbr @bbbbbr.bsky.social · 15/03/2026
Small update to #QRPaint (v0.9.3) that adds selectable fill style for the Circle and Rectangle tools. bbbbbr.itch.io/game-boy-qr-... #Gameboy #Megaduck #pixelart
Screenshot of qrpaint in a game boy emulator, there is a drawing of a smiley face and lots of overlapping circles and linesScreenshot of qrpaint in a game boy emulator, the whole screen is dimmed except a small area around the fill-style selector with three types, hollow, foreground-fill, background-fill
0164
Reposted by bbbbbr
GBDK-2020 @gbdk2020.gbdk.org · 13/03/2026
CrossZGB v2026.1 is out! A C & ASM Game Engine for #GameBoy #GameBoyColor #SMS #GameGear #MegaDuck - New quality of life features and improvements for sprite management - New examples for sub-pixel movement and Z-order control - Fixes for music drivers github.com/gbdk-2020/Cr...
Cross ZGB logo Showing a game controller D-Pad and text with dithered fades from orange to black top to bottom on a yellow background
01810
bbbbbr @bbbbbr.bsky.social · 10/03/2026
New version of QR-Paint with some fun features: - Draw with #SNES Mouse when plugged into a Super #GameBoy (building on demo by vinheim3) - Windows XP desktop themed SGB Border - #MegaDuck build with Printer support #retrogaming #pixelart #qrpaint bbbbbr.itch.io/game-boy-qr-...
Photo of a handheld Super Nintendo clone (supaboy) with a controller and mouse plugged into the front and a Super Game Boy plugged into the top. On the screen is the QR-Paint interface with a dogcow drawing surrounded by a PC desktop like image with green hills and a blue sky with clouds.
15912
bbbbbr @bbbbbr.bsky.social · 07/03/2026
The output size of the #GameBoy printer is cute, but the larger print format of the #MegaDuck (a Game Boy clone) printer is much better for pinning up or the fridge door. (coming soon to #QRPaint: a Mega Duck port) GB on left, Duck on right #retrogaming
Side by side comparisons of the Game Boy Printer and Mega Duck printer with images. Both showing prints of a dogcow and flower. The game boy prints are about 1 inch tall and the Mega Duck ones are about 2 inches tall
1131
bbbbbr @bbbbbr.bsky.social · 23/02/2026
Thanks for the kind words, drawings and suggestions about #QRPaint! New version updates -Game Boy Printer support -Hold B for fast cursor -Analogue Pocket build GB Printer had light testing, let me know about issues bbbbbr.itch.io/game-boy-qr-... #GBDK #RetroGaming #PixelArt #GameBoyColor #GameBoy
Screenshot of a Game Boy Printer Emulator with two printed images. One is a dogcow drawn in QR-Paint, and the other is the same drawing but the dogcow has a mohawk
1131
bbbbbr @bbbbbr.bsky.social · 19/02/2026
What if you could misuse a @furrtek.bsky.social GB-303 music cart as an etch-a-sketch in QR-Paint? Just trying it out, so far not planning to make it a formal part of #QRPaint since it would result in some feature limitations. #GameBoy #EtchASketch
4283
Reposted by bbbbbr
Toenail @flyingvee.bsky.social · 17/02/2026
By jove it works...
2154
bbbbbr @bbbbbr.bsky.social · 17/02/2026
Draw on the Game Boy and share direct to your phone with a #QRCode! No extra hardware and without the internet. QR-Paint is a small paint program for the #GameBoy with a fun way to export drawings. bbbbbr.itch.io/game-boy-qr-... #GBDK #RetroGaming #PixelArt #GameBoyColor
1123781
Reposted by bbbbbr
Lowki Sapfoot @lowkisapfoot.bsky.social · 15/02/2026
1,000 Wordyl wins!!
231
bbbbbr @bbbbbr.bsky.social · 03/02/2026
Been working on something fun. More details "coming soon" (TM). #GameBoy #Retrogaming #Pixelart
Photo of a Translucent Purple Game Boy Color. The screen is mostly filled with a black and white QRCode
3333
bbbbbr @bbbbbr.bsky.social · 15/01/2026
Full 2025 #GameBoy homebrew / indie Cart Release charts. Holding steady but 2022 was still peak. Big publishers down a bit, self-published up. Now with interactive web charts (links in reply) Data from @dmgpage.bsky.social : dmgpage.com/homebrew-rel... #gbdev #retrogaming #indiedev #retrodev
Bar chart with the following data:
Count - System	System		
Year	GB	GB/C	GBC
2013	1		
2014	1	1	
2015	1		
2016	2		
2017	3	1	1
2018	4		1
2019	9	3	1
2020	12	2	4
2021	24	7	9
2022	39	10	14
2023	20	9	17
2024	19	12	20
2025	12	12	27
Bar Chart with the following data
Publisher	2013	2014	2015	2016	2017	2018	2019	2020	2021	2022	2023	2024	2025	Total Result
incube8 Games									2	8	5	5	1	21
Ferrante Crafts									1	15	3	1		20
Game Impact							3	5	7	3				18
Bitmap Soft									3	2	3	5	1	14
ModRetro												6	8	14
Catskull Electronics		1			1	1	4	2	4					13
Broke Studio											1	3	5	9
insideGadgets									1	4	3	1		9
Johndo										3	3	3		9
Limited Run Games											4	2	2	8
Yastuna Games									1	2	5			8
Greenboy Games						1	2	2	1	1				7
asm		1	1		2			1						5
RetroRoomgames								1		3		1		5
Guardian Games Studio											1	1	2	4
1st Press Games							1		1			1		3
Community Releases						1	1		1					3
Game Buoy Games							1	1	1					3
Mega Cat Studios						1	1				1			3
Spacebot Interactive								1	1	1				3
Studio Loading Productions										1		1	1	3
Tg Virtual								1	2					3
Bar Chart with the following data
Publisher	2013	2014	2015	2016	2017	2018	2019	2020	2021	2022	2023	2024	2025
incube8 Games									2	8	5	5	1
Ferrante Crafts									1	15	3	1	
Game Impact							3	5	7	3			
Bitmap Soft									3	2	3	5	1
ModRetro												6	8
Catskull Electronics		1			1	1	4	2	4				
Broke Studio											1	3	5
insideGadgets									1	4	3	1	
Johndo										3	3	3	
Limited Run Games											4	2	2
Yastuna Games									1	2	5		
Greenboy Games						1	2	2	1	1			
asm		1	1		2			1					
RetroRoomgames								1		3		1	
Guardian Games Studio											1	1	2
1st Press Games							1		1			1	
Community Releases						1	1		1				
Game Buoy Games							1	1	1				
Mega Cat Studios						1	1				1		
Spacebot Interactive								1	1	1			
Studio Loading Productions										1		1	1
Tg Virtual								1	2				
Benjamin McCarthy												1	1
Cat Graffam										1		1	
EligosGames										1			1
Ice Cold Blood													2
island time											2		
Jankenpopp								1		1			
Magic Quest Media												1	1
OokamiTheWolf1									1	1			
Orionsoft					1						1		
PC Nono Games												1	1
Phoenix Ware										1		1	
PixelHeart												2	
Prodigious Pineapple Productions									1		1		
Remute									1				1
RetroGameShop												2	
RubenRetro											1		1
Studio 40A										1			1
Sweet 8-Bitterness										1	1		
Tronimal				1					1				
Yliader									1	1			
?										1
2144
bbbbbr @bbbbbr.bsky.social · 06/01/2026
Did the yearly update to my web list of #GameBoy flash cart vendors & options. A couple carts went in/out of stock. Prices didn't change much (unclear if tariffs apply) New vendor is "GB Make" but they lack specifics such as MBC type, SRAM size, etc. bbbbbr.github.io/GameBoy-Flas...
bbbbbr.github.io
GameBoy-Flash-Carts
List of Game Boy Flash Cart Vendors and Options
3141
bbbbbr @bbbbbr.bsky.social · 04/01/2026
The Year Wrapped for #GBDK & #ZGB! 2025, another good year for releases! Here's a browse of #GameBoy, #NES & #SMS/#GameGear games people made with #GBDK2020. Check out the gallery & give some a try, most free to download & play. gbdk-2020.github.io/gbdk-2020-ga... #indiedev #retrogaming #retrodev
43915
bbbbbr @bbbbbr.bsky.social · 04/01/2026
Finished Infinity- had a great time. Gameplay and difficulty were reasonably balanced (bit easier than expected), UI worked well, overall polished and well done. Long time since playing an rpg, was a decent return to the genre. Congrats to the team on finishing development. #infinitygbc #gameboy
Photograph of a Game Boy screen showing the the words The End in stylized, pixelated golidsh text on as dark background
1171
bbbbbr @bbbbbr.bsky.social · 02/01/2026
Carrot successfully delivered to goat. Would be ok with this as an alternate end to the game. 😅 #infinitygbc #gameboy #gameboycolor
photograph of the game boy color game infinity gbc running on a non-backlit gbboy colour clone. there is a goat in a half grazed meadow with some trees and four player characters nearby
1130
Reposted by bbbbbr
GBDK-2020 @gbdk2020.gbdk.org · 28/12/2025
CrossZGB v2025.1 is out! A Game Engine for #GameBoy #SMS #GameGear #MegaDuck - Improved performance - Improved coroutines - Level maps larger than 256 tiles - Attribute maps for the SMS/GG - Persistent sprites - Linker files to allow for large projects - New examples github.com/gbdk-2020/Cr...
github.com
Release Cross ZGB v2025.1 · gbdk-2020/CrossZGB
CrossZGB is a multi-platform game engine that lets you write your own games in C or assembly for the several popular consoles. New features and improvements Improve performance Improve the built i...
0121
Reposted by bbbbbr
GBDK-2020 @gbdk2020.gbdk.org · 28/12/2025
#GBDK 2020 v4.5.0 is out! - HRAM allocation + example - SRAM Bank new # pragma_dataseg - zx0 compression - png2asset fixes and features - Many other fixes & features New examples! - MBC5 Rumble - SNES NMI handler - #MegaDuck Printer github.com/gbdk-2020/gb... #gbdev #smsdev #nesdev
Image of the GBDK-2020 project name in pixel font with a drop shadow and a orange and purple background
21710
bbbbbr @bbbbbr.bsky.social · 21/12/2025
Woo! I've updated my #MegaDuck ROM patch on itch for Fydo's Magic Tiles to note that the source ROM is now **pay what you want**. 🎉 Recommend checking out this charming puzzle game for the Game Boy *and* Mega Duck. :) bbbbbr.itch.io/megaduck-pat...
bbbbbr.itch.io
Mega Duck patch for Fydo's Magic Tiles (Game Boy) by bbbbbr
A ROM patch for Fydo's Magic Tiles (Game Boy) so it can run on the Mega Duck
0214
Reposted by bbbbbr
ManCloud (Chris) @mancloud.bsky.social · 16/12/2025
#MegaDuck Super Junior Computer gets reversed! I invested several hours to pull "proper" schematics out of the PCBs and shared them on GitHub. During the process I also completely redrew the MainBaord PCB surrounding the CPU.
162